# tests.platform.linux.test_vm_helper - linux vm helper tests
#
# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#         Manuel de la Pena <manuel@canonical.com>
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
import os

from contrib.testing.testcase import environ
from tests.syncdaemon.test_vm import BaseVolumeManagerTests

from ubuntuone.platform.linux.vm_helper import get_udf_path_name


class VMHelperTest(BaseVolumeManagerTests):
    """Test the vm_helper methods on linux."""

    def test_get_udf_path_name(self):
        """Test for _get_udf_path_name."""
        home_dir = '/home/ubuntuonehacker'
        in_home = os.path.join(home_dir, 'foo')
        deep_in_home = os.path.join(home_dir, 'docs', 'foo', 'bar')
        outside_home = os.path.join('/', 'home', 'other', 'foo')
        relative_home = '../../home/foo/bar'
        with environ('HOME', home_dir):
            path, name = get_udf_path_name(in_home)
            self.assertEquals('~', path)
            self.assertEquals('foo', name)
            path, name = get_udf_path_name(deep_in_home)
            self.assertEquals('~/docs/foo', path)
            self.assertEquals('bar', name)
            self.assertRaises(ValueError, get_udf_path_name, outside_home)
            self.assertRaises(ValueError, get_udf_path_name, None)
            self.assertRaises(ValueError, get_udf_path_name, relative_home)

