# -*- coding: utf-8 -*-
#
# Author: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Tests for the Ubuntu One credentials management IPC service."""

from twisted.internet import defer
from twisted.trial.unittest import TestCase

from ubuntuone.platform.windows import credentials

TEST_APP_NAME = "test application"

TEST_CREDENTIALS = {
    "token": "1234token",
}


class FakeSSOProxy(object):
    """A fake SSOProxy."""

    def find_credentials(self, app_name, options, **kwargs):
        """Ask the U1 credentials."""
        return defer.succeed(TEST_CREDENTIALS)


class CredentialsManagementTestCase(TestCase):
    """Tests for CredentialsManagement."""

    timeout = 5

    def setUp(self):
        """Initialize these tests."""
        self.proxy = FakeSSOProxy()
        self.cm = credentials.CredentialsManagement(self.proxy)

    def test_find_credentials(self):
        """Test the find_credentials method."""
        d = defer.Deferred()
        ok = lambda: d.callback("ok")
        error = lambda *args: d.errback(args)
        self.cm.find_credentials(reply_handler=ok, error_handler=error)
        return d

    def test_register_to_credentials_found(self):
        """Test the register_to_credentials_found method."""
        cb = lambda creds: self.assertEqual(creds, TEST_CREDENTIALS)
        other_cb = self.cm.register_to_credentials_found(cb)
        other_cb(TEST_APP_NAME, TEST_CREDENTIALS)

    def test_register_to_credentials_not_found(self):
        """Test the register_to_credentials_not_found method."""
        cb = lambda: None
        other_cb = self.cm.register_to_credentials_not_found(cb)
        other_cb(TEST_APP_NAME)
