# ubuntuone.platform.linux.vm_helper- vm helpers for linux.
#
# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""vm helpers for linux."""
import os


platform = "linux"


def create_shares_link(source, dest):
    """Create the shares symlink."""
    if not os.path.exists(dest):
        # remove the symlink if it's broken
        if os.path.islink(dest) and \
           os.readlink(dest) != source:
            os.remove(dest)
        os.symlink(source, dest)
        return True
    else:
        return False


def get_udf_path_name(path):
    """Return (path, name) from path.

    path must be a path inside the user home direactory, if it's not
    a ValueError is raised.
    """
    if not path:
        raise ValueError("no path specified")

    user_home = os.path.expanduser('~')
    start_list = os.path.abspath(user_home).split(os.path.sep)
    path_list = os.path.abspath(path).split(os.path.sep)

    # Work out how much of the filepath is shared by user_home and path.
    common_prefix = os.path.commonprefix([start_list, path_list])
    if os.path.sep + os.path.join(*common_prefix) != user_home:
        raise ValueError("path isn't inside user home: %r" % path)

    i = len(common_prefix)
    rel_list = [os.path.pardir] * (len(start_list)-i) + path_list[i:]
    relpath = os.path.join(*rel_list)
    head, tail = os.path.split(relpath)
    if head == '':
        head = '~'
    else:
        head = os.path.join('~', head)
    return head, tail


def get_udf_path(suggested_path):
    """Build the udf path using the suggested_path."""
    # Unicode boundary! the name is Unicode in protocol and server,
    # but here we use bytes for paths
    return os.path.expanduser(suggested_path).encode("utf8")


def get_share_path(share):
    """Builds the root path of a share using the share information."""
    if hasattr(share, 'volume_id'):
        share_id = share.volume_id
    elif hasattr(share, 'share_id'):
        share_id = share.share_id
    else:
        share_id = share.id

    if hasattr(share, 'name'):
        share_name = share.name
    else:
        share_name = share.share_name

    if hasattr(share, 'other_visible_name'):
        visible_name = share.other_visible_name
    else:
        visible_name = share.from_visible_name

    if visible_name:
        dir_name = '%s (%s, %s)' % (share_name, visible_name, share_id)
    else:
        dir_name = '%s (%s)' % (share_name, share_id)

    # Unicode boundary! the name is Unicode in protocol and server,
    # but here we use bytes for paths
    dir_name = dir_name.encode("utf8")

    return dir_name

