# ubuntuone.platform.windows.vm_helper- vm helpers for windows.
#
# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""vm helpers for windows."""

import os
from ubuntuone.platform.windows.os_helper import (
    LONG_PATH_PREFIX,
    make_link,
    abspath)

def create_shares_link(source, dest):
    """Create the shares symlink."""
    make_link(source, dest)
    return True


def get_udf_path_name(path):
    """Return (path, name) from path.

    path must be a path inside the user home direactory, if it's not
    a ValueError is raised.
    """
    if not path:
        raise ValueError("no path specified")

    user_home = os.path.expanduser('~')
    start_list = os.path.abspath(user_home).split(os.path.sep)
    path_list = os.path.abspath(path).split(os.path.sep)

    # Work out how much of the filepath is shared by user_home and path.
    common_prefix = os.path.commonprefix([start_list, path_list])
    prefix = os.path.expandvars('%HOMEDRIVE%') + os.path.sep
    if len(common_prefix ) > 1:
        prefix += os.path.join(*common_prefix[1:])
    if prefix != user_home:
        raise ValueError("path isn't inside user home: %r" % path)

    i = len(common_prefix)
    rel_list = [os.path.pardir] * (len(start_list) - i) + path_list[i:]
    relpath = os.path.join(*rel_list)
    head, tail = os.path.split(relpath)
    if head == '':
        head = '~'
    else:
        head = os.path.join('~', head)
    # the head has to be a canonical path that uses / as the separator
    # because is information used by the server side to create the file it
    # it correct location.
    head = head.replace('/', '\\')
    return head, tail


def get_udf_path(suggested_path):
    """Build the udf path using the suggested_path."""
    path = suggested_path.replace('/', '\\')
    return LONG_PATH_PREFIX + os.path.expanduser(path).encode("utf8")


def get_share_path(share):
    """Builds the root path of a share using the share information."""
    if hasattr(share, 'volume_id'):
        share_id = share.volume_id
    elif hasattr(share, 'share_id'):
        share_id = share.share_id
    else:
        share_id = share.id

    if hasattr(share, 'name'):
        share_name = share.name
    else:
        share_name = share.share_name

    if hasattr(share, 'other_visible_name'):
        visible_name = share.other_visible_name
    else:
        visible_name = share.from_visible_name

    if visible_name:
        dir_name = '%s (%s, %s)' % (share_name, visible_name, share_id)
    else:
        dir_name = '%s (%s)' % (share_name, share_id)

    # Unicode boundary! the name is Unicode in protocol and server,
    # but here we use bytes for paths
    dir_name = dir_name.encode("utf8")

    return abspath(dir_name)
